@@ -4,10 +4,8 @@ from .model import IpAPIResponse, MembersAPIResponse, PlayerInfoRodinaAPIRespons
     PlayerInfoNotFound
 
 from .api import get, post
-
 from typing import Literal
 import asyncio
-
 from pydantic import parse_obj_as, ValidationError
 
 
@@ -26,24 +24,33 @@ class VprikolAPI:
 
         return IpAPIResponse(**result.data)
 
-    async def get_members(self, server_id: int, fraction_id: int) -> MembersAPIResponse:
-        result = await get(url=f'{self.base_url}members', headers=self.headers, params={'server': server_id,
+    async def get_members(self, server_id: int, fraction_id: int | list[int]) -> dict[str, MembersAPIResponse]:
+        result = await get(url=f'{self.base_url}members', headers=self.headers, params={'server_id': server_id,
                                                                                         'fraction_id': fraction_id})
         if not result.success:
             raise Exception(result.error)
+        response = {}
+        for fraction_id in result.data:
+            players = []
+            if not fraction_id.isdigit():
+                continue
+            for player in result.data[fraction_id]['players']:
+                players.append({'username': player, 'id': result.data[fraction_id]['players'][player]['id'],
+                                'isOnline': result.data[fraction_id]['players'][player]['isOnline'],
+                                'isLeader': result.data[fraction_id]['players'][player]['isLeader'],
+                                'rank': result.data[fraction_id]['players'][player]['rank'],
+                                'rankLabel': result.data[fraction_id]['players'][player]['rankLabel'],
+                                'ingameId': result.data[fraction_id]['players'][player]['ingameId'],
+                                'lvl': result.data[fraction_id]['players'][player]['lvl'],
+                                'ping': result.data[fraction_id]['players'][player]['ping'],
+                                'color': result.data[fraction_id]['players'][player]['color']})
+            result.data[fraction_id]['players'] = players
+            response[fraction_id] = MembersAPIResponse(**result.data[fraction_id])
 
-        players = []
-        for player in result.data['players']:
-            players.append({'username': player, 'id': result.data['players'][player]['id'],
-                            'isOnline': result.data['players'][player]['isOnline'],
-                            'isLeader': result.data['players'][player]['isLeader'],
-                            'rank': result.data['players'][player]['rank'],
-                            'rankLabel': result.data['players'][player]['rankLabel']})
-        result.data['players'] = players
-        return MembersAPIResponse(**result.data)
+        return response
 
-    async def get_player_information(self, server_id: int, nickname: str) -> PlayerInfoRodinaAPIResponse\
-                                                                             | PlayerInfoArizonaAPIResponse\
+    async def get_player_information(self, server_id: int, nickname: str) -> PlayerInfoRodinaAPIResponse \
+                                                                             | PlayerInfoArizonaAPIResponse \
                                                                              | PlayerInfoNotFound:
         task = await post(url=f'{self.base_url}find/createTask', headers=self.headers,
                           params={'server': server_id, 'nick': nickname})
@@ -52,11 +59,11 @@ class VprikolAPI:
 
         task = CreatedFindTaskAPIResponse(**task.data)
         while True:
-            await asyncio.sleep(1)
             result = await get(url=f'{self.base_url}find/getTaskResult', headers=self.headers,
                                params={'request_id': task.request_id})
 
             if not result.success and result.error.error_code and result.error.error_code == 425:
+                await asyncio.sleep(1)
                 continue
 
             if result.error and result.error.error_code == 422:
